<?php

namespace Drupal\node_parts\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\node_parts\Event\ViewModeEvent;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Node Parts routes.
 */
final class NodePartsController extends ControllerBase {

  /**
   * The renderer service.
   *
   * @var \Drupal\node_parts\Renderer
   */
  protected $renderer;

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $currentRouteMatch;

  /**
   * The event dispatcher service.
   *
   * @var \Symfony\Component\EventDispatcher\EventDispatcherInterface
   */
  protected $eventDispatcher;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->renderer = $container->get('renderer');
    $instance->currentRouteMatch = $container->get('current_route_match');
    $instance->eventDispatcher = $container->get('event_dispatcher');

    return $instance;
  }

  /**
   * Builds the response.
   */
  public function __invoke(): array {
    // Get the current entity from the route match.
    $node = $this->currentRouteMatch->getParameter('node');
    if (!is_a($node, 'Drupal\node\NodeInterface')) {
      // If the entity is not a node entity, return an empty array.
      return [];
    }

    // Get translated node if available.
    $langcode = $this->languageManager()->getCurrentLanguage()->getId();
    if ($node->hasTranslation($langcode)) {
      $node = $node->getTranslation($langcode);
    }

    // Set the view mode to 'full' by default.
    $view_mode = 'full';
    $event = new ViewModeEvent($view_mode);
    // Let other modules alter the view mode.
    $this->eventDispatcher->dispatch($event, ViewModeEvent::class);
    $view_mode = $event->getViewMode();

    $build = $this->entityTypeManager()
      ->getViewBuilder($node->getEntityTypeId())->view($node, $view_mode, $langcode);
    $build['#cache']['contexts'][] = 'url.path';

    $this->renderer->render($build, $node);

    return $build;
  }

}
