<?php

namespace Drupal\node_parts\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Defines the AllowedViewModesEvent class.
 *
 * This event is dispatched when the allowed view modes are being set.
 * Call from Renderer::render() method.
 */
class AllowedViewModesEvent extends Event {

  /**
   * The allowed view modes.
   *
   * @var array
   */
  protected $viewModes;

  /**
   * Constructs the AllowedViewModesEvent object.
   *
   * @param array $view_modes
   *   The allowed view modes.
   */
  public function __construct(array $view_modes) {
    $this->viewModes = $view_modes;
  }

  /**
   * Gets the allowed view modes.
   *
   * @return array
   *   The allowed view modes.
   */
  public function getViewModes(): array {
    return $this->viewModes;
  }

  /**
   * Sets the allowed view modes.
   *
   * @param array $view_modes
   *   The allowed view modes.
   */
  public function setViewModes(array $view_modes) {
    $this->viewModes = $view_modes;
  }

}
