<?php

namespace Drupal\node_parts\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Defines the RequiredFieldsEvent class.
 *
 * This event is dispatched when the required fields are being set.
 * Call from Preprocess::preprocess() to alter the variables.
 */
class LinkAlterEvent extends Event {

  /**
   * The fields that are required.
   *
   * @var array
   */
  protected $variables;

  /**
   * Constructs a RequiredFieldsEvent object.
   *
   * @param array $fields
   *   The fields that are required.
   */
  public function __construct(array $fields) {
    $this->variables = $fields;
  }

  /**
   * Gets the fields that are required.
   *
   * @return array
   *   The fields that are required.
   */
  public function getVariables(): array {
    return $this->variables;
  }

  /**
   * Sets the fields that are required.
   *
   * @param array $variables
   *   The fields that are required.
   */
  public function setVariables(array $variables) {
    $this->variables = $variables;
  }

}
