<?php

namespace Drupal\node_parts\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Defines the RequiredFieldsEvent class.
 *
 * This event is dispatched when the required fields are being set.
 * Call the Renderer::render() method to render the fields.
 */
class RequiredFieldsEvent extends Event {

  /**
   * The fields that are required.
   *
   * @var array
   */
  protected $fields;

  /**
   * Constructs a RequiredFieldsEvent object.
   *
   * @param array $fields
   *   The fields that are required.
   */
  public function __construct(array $fields) {
    $this->fields = $fields;
  }

  /**
   * Gets the fields that are required.
   *
   * @return array
   *   The fields that are required.
   */
  public function getFields(): array {
    return $this->fields;
  }

  /**
   * Sets the fields that are required.
   *
   * @param array $fields
   *   The fields that are required.
   */
  public function setFields(array $fields) {
    $this->fields = $fields;
  }

}
