<?php

namespace Drupal\node_parts\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Defines the ViewModeEvent class.
 *
 * This event is dispatched when the view mode is being set.
 * Call the NodePartsController::__invoke() method to set the view mode.
 */
class ViewModeEvent extends Event {

  /**
   * The allowed view modes.
   *
   * @var string
   */
  protected $viewMode;

  /**
   * Constructs a ViewModeEvent object.
   *
   * @param string $view_mode
   *   The fields that are required.
   */
  public function __construct(string $view_mode) {
    $this->viewMode = $view_mode;
  }

  /**
   * Gets the view mode to render.
   *
   * @return string
   *   The view mode.
   */
  public function getViewMode(): string {
    return $this->viewMode;
  }

  /**
   * Sets the view mode to render.
   *
   * @param string $view_mode
   *   The view mode.
   */
  public function setViewMode(string $view_mode) {
    $this->viewMode = $view_mode;
  }

}
